@@ -28,6 +28,9 @@ use Daje::Workflow::Database::Model::History;
 #
 #     $data->insert_history("History");
 #
+#     $data->save_context($context);
+#
+#     $data->save_workflow($workflow);
 #
 # REQUIRES
 # ========
@@ -64,7 +67,7 @@ use Daje::Workflow::Database::Model::History;
 # janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
 #
 
-our $VERSION = "0.14";
+our $VERSION = "0.15";
 
 has 'db';               # Constructor
 has 'workflow_pkey';    # Constructor
@@ -110,6 +113,12 @@ sub load_context($self) {
         context       => $self->context,
     )->load_fk();
 
+    my $new_context = $self->context();
+    if(exists $new_context->{context}) {
+        foreach my $key(keys %{$new_context->{context}}) {
+            $context->{context}->{$key} = $new_context->{context}->{$key};
+        }
+    }
     $self->context($context);
     return;
 }
@@ -150,6 +159,7 @@ __END__
 
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -177,6 +187,9 @@ Daje::Workflow::Database::Model - is the data models used by Daje-Workflow
 
     $data->insert_history("History");
 
+    $data->save_context($context);
+
+    $data->save_workflow($workflow);
 
 
 
